# wpsrpc-sdk
WPS Office for Linux RPC API SDK

The C++ SDK headers was taken from [wps_cpp](https://code.aliyun.com/zouyingfeng/wps/tree/master/cpp) with *no changes*:
```
Copyright @ 2012-2019, Kingsoft office,All rights reserved.
```

The lib/x86_64 was extracted from [official package](https://wps-linux-personal.wpscdn.cn/wps/download/ep/Linux2023/17900/wps-office_12.1.0.17900_amd64.deb)
